@@ -6,7 +6,7 @@
 #include <qapplication.h>
 #include <qfiledialog.h>
 #include <qmessagebox.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qtabwidget.h>
 #include <qlistview.h>
 #include <qlistbox.h>
@@ -18,10 +18,9 @@
 #include <qtextstream.h>
 #include <qstring.h>
 #include <stdlib.h>
+#include <qregexp.h>
 #include "qpkg.h"
-#ifdef DESKTOP_VERSION
-#include "config.h"
-#else
+#ifndef DESKTOP_VERSION
 #include <qtopia/config.h>
 #endif
 #ifdef QWS
@@ -31,6 +30,11 @@
 #include <stdlib.h>
 #include <sys/vfs.h>
 
+#include <iostream>
+using namespace std;
+
+
+
 qpkg::qpkg( QWidget *parent, const char *name )
     : qpkgBase( parent, name ), ipkgRunning(false)
 {
@@ -39,89 +43,91 @@ qpkg::qpkg( QWidget *parent, const char *name )
     connect( proc, SIGNAL(readyReadStderr()), this, SLOT(readFromStderr()) );
     connect( proc, SIGNAL(processExited()), this, SLOT(ipkgFinished()) );
 
+    log_view->setTextFormat(PlainText);
+
+    QFile optionsFile("/etc/ipkg.conf");
+    if (optionsFile.open(IO_ReadOnly)) {
+      QTextStream options(&optionsFile);
+      QString line;
+      QRegExp source( "^src\\s+(\\S+)\\s+(\\S+)" );
+      QRegExp dest("^dest\\s+(\\S+)\\s+(\\S+)");
+      QRegExp httpproxy("^(#\\s)?option\\s+http_proxy\\s+(\\S+)");
+      QRegExp ftpproxy("^(#\\s)?option\\s+ftp_proxy\\s+(\\S+)");
+      QRegExp proxyusername("^option\\s+proxy_username\\s+(\\S+)");
+      QRegExp proxypassword("^option\\s+proxy_password\\s+(\\S+)");
+
+      while ((line=options.readLine())!= NULL) {
+	if ((source.search(line)!=-1)  && (dest.numCaptures()==2)){
+	      feeds.push_back(source.cap(1) + " " + source.cap(2));
+	} else
+	  if ((dest.search(line)!=-1) && (dest.numCaptures()==2)) {
+		dests.push_back(Dest(dest.cap(1),dest.cap(2)));
+        } else 
+	  if (httpproxy.search(line)!=-1) {
+	     httpProxyLine->setText(httpproxy.cap(2));
+	     if (httpproxy.cap(1)=="") {
+	       httpProxyEnable->setChecked(true);
+            } else {
+               httpProxyEnable->setChecked(false);
+	    }
+	} else 
+	  if (ftpproxy.search(line)!=-1) {
+	        ftpProxyLine->setText(ftpproxy.cap(2));
+		if (ftpproxy.cap(1)=="") {
+		  ftpProxyEnable->setChecked(true);
+            } else {
+		  ftpProxyEnable->setChecked(false);
+	    }
+	  } else 
+	  if (proxyusername.search(line)!=-1) {
+	    loginLine->setText(proxyusername.cap(1));
+	    
+	} else 
+	  if (proxypassword.search(line)!=-1) {
+	    passwdLine->setText(proxypassword.cap(1));
+	} 
+      }
+    }
+
+
     ipkg_listview->clear();
-    updateListView("/");
-    updateListView("/mnt/card");
-    updateListView("/mnt/cf");
-    updateListView("/mnt/net");
-    updateListView("/mnt/user");
+    for (unsigned int i=0;i<dests.size();i++) {
+      updateListView(dests[i].path);
+    }
     updateNewListView();
     
-    Config *conf = new Config("Packager");
-    conf->setGroup("Feeds");
-    int numf = conf->readNumEntry("NumFeeds", 0);
+
     FeedListBox->clear();
-    if (numf) {
-	for (int i = 0; i < numf; i++) {
-	    QString xxx = "Feed"+ QString::number(i);
-	    QString feedstr = conf->readEntry(xxx);
-	    FeedListBox->insertItem(feedstr);
-	}
-	conf->setGroup("Default");
-	numf = conf->readNumEntry("CurrentFeed");
-	FeedListBox->setCurrentItem(numf);
-    } else {
-#ifdef QT_QWS_IPAQ
-	FeedListBox->insertItem("http://mirror1.pdaXrom.org/current-ipaq/feed/");
-#elif QT_QWS_SL5XXX
-	FeedListBox->insertItem("http://mirror1.pdaXrom.org/current-collie/feed/");
-#else
-	FeedListBox->insertItem("http://mirror1.pdaXrom.org/current/feed/");
-#endif
+    for (unsigned int i=0;i<feeds.size();i++){
+      FeedListBox->insertItem(feeds[i]);
     }
-    conf->setGroup("Proxy");
-    httpProxyLine->setText(conf->readEntry("Http",""));
-    ftpProxyLine->setText(conf->readEntry("Ftp",""));
-    loginLine->setText(conf->readEntry("Username",""));
-    passwdLine->setText(conf->readEntry("Password",""));
-    httpProxyEnable->setChecked(conf->readBoolEntry("HttpOn"));
-    ftpProxyEnable->setChecked(conf->readBoolEntry("FtpOn"));
-    delete conf;
+    FeedListBox->setCurrentItem(feeds.size());
+
     update_iconf();
     update_storages();
 }
 
 qpkg::~qpkg()
 {
-    Config *conf = new Config("Packager");
-    conf->setGroup("Default");
-    conf->writeEntry("CurrentFeed", FeedListBox->currentItem());
-    conf->setGroup("Feeds");
-    conf->clearGroup();
-    conf->writeEntry("NumFeeds", (int)FeedListBox->count());
-    for (unsigned int i=0; i<FeedListBox->count(); i++) {
-	QString xxx = "Feed"+ QString::number(i);
-        conf->writeEntry(xxx, FeedListBox->text(i));
-    }
-    conf->setGroup("Proxy");
-    conf->clearGroup();
-    conf->writeEntry("Http", httpProxyLine->text());
-    conf->writeEntry("Ftp", ftpProxyLine->text());
-    conf->writeEntry("Username", loginLine->text());
-    conf->writeEntry("Password", passwdLine->text());
-    conf->writeEntry("HttpOn", httpProxyEnable->isChecked());
-    conf->writeEntry("FtpOn", ftpProxyEnable->isChecked());
-    delete conf;
+
 }
 
 void qpkg::update_storages()
 {
     dest_box->clear();
-    update_storage("/"        );
-    update_storage("/mnt/cf"  );
-    update_storage("/mnt/hd"  );
-    update_storage("/mnt/card");
-    update_storage("/mnt/net" );
-    update_storage("/mnt/user");
+    for (unsigned int i=0;i<dests.size();i++){
+      update_storage(dests[i].path);
+    }
 }
 
 void qpkg::update_storage( QString disk)
 {
+ 
     struct statfs buf;
-    QString str;
-    if (disk == "/mnt/user") str = "mount | grep '/home'";
-    else str = "mount | grep '" + disk + "'";
+    QString str = "mount | grep '" + disk + "'";
+ 
     if ((!statfs(disk, &buf)) && (system(str) == 0)) {
+ 
 	//long free = buf.f_bavail;
 	//long bs = buf.f_bsize;
 	//fprintf(stderr, "%ld %ld\n", free, bs);
@@ -265,12 +271,14 @@ void qpkg::remove_ipkg()
 
 void qpkg::readFromStdout()
 {
-    log_view->append( proc->readStdout() );
+   log_view->moveCursor(QTextEdit::MoveEnd,false);
+   log_view->insert(proc->readStdout() );
 }
 
 void qpkg::readFromStderr()
 {
-    log_view->append( proc->readStderr() );
+  log_view->moveCursor(QTextEdit::MoveEnd,false);
+  log_view->insert( proc->readStderr() );
 }
 
 void qpkg::ipkgFinished()
@@ -288,11 +296,9 @@ void qpkg::ipkgFinished()
 #endif
     ipkgRunning = false;
     ipkg_listview->clear();
-    updateListView("/");
-    updateListView("/mnt/card");
-    updateListView("/mnt/cf");
-    updateListView("/mnt/net");
-    updateListView("/mnt/user");
+    for (unsigned int i=0;i<dests.size();i++) {
+      updateListView(dests[i].path);
+    }
     new_listview->clear();
     updateNewListView();
     install_button->setEnabled(true);
@@ -429,8 +435,9 @@ void qpkg::reload_ipkg()
 
 void qpkg::add_feed()
 {
-    FeedListBox->insertItem(NewFeedLineEdit->text());
+  FeedListBox->insertItem(NewNameLineEdit->text().stripWhiteSpace() + " " + NewFeedLineEdit->text().stripWhiteSpace());
     NewFeedLineEdit->setText("");
+    NewNameLineEdit->setText("");
     FeedListBox->setCurrentItem(FeedListBox->count()-1);
     update_iconf();
 }
@@ -443,31 +450,34 @@ void qpkg::remove_feed()
 
 void qpkg::edit_feed()
 {
-    NewFeedLineEdit->setText(FeedListBox->currentText());
+  NewNameLineEdit->setText(FeedListBox->currentText().section(" ",0,0));  
+  NewFeedLineEdit->setText(FeedListBox->currentText().section(" ",1,1));
 }
 
 void qpkg::update_iconf()
 {
+   
     QFile options("/etc/ipkg.conf");
     if ( options.open(IO_WriteOnly) ) {
 	QTextStream opt(&options);
 	for (unsigned int i=0; i<FeedListBox->count(); i++) {
-	    opt << "src feed" << i << " " << FeedListBox->text(i) << "\n";
+	    opt << "src " << FeedListBox->text(i) << "\n";
+	}
+        for (unsigned int i=0; i< dests.size();i++) {
+	  opt << "dest"  << " " << dests[i].name << " " << dests[i].path <<endl;
 	}
 
-	opt << "dest root /\n";
-	opt << "dest cf /mnt/cf\n";
-	opt << "dest sd /mnt/card\n";
-	opt << "dest net /mnt/net\n";
-	opt << "dest ide /mnt/ide\n";
-	opt << "dest user /mnt/user\n";
-
-	opt << "dest tmpinst /home/tmp/ipkg/inst\n";
-	if (!httpProxyLine->text().isEmpty() && httpProxyEnable->isChecked()) {
+	if (!httpProxyLine->text().isEmpty()) {
+	    if (! httpProxyEnable->isChecked()) {
+	      opt << "# "; 
+	    }
 	    opt << "option http_proxy " << httpProxyLine->text() << "\n";
 	}
-	if (!ftpProxyLine->text().isEmpty() && ftpProxyEnable->isChecked()) {
-	    opt << "option ftp_proxy " << ftpProxyLine->text() << "\n";
+	if (!ftpProxyLine->text().isEmpty()) {
+	  if (! ftpProxyEnable->isChecked()) {
+            opt << "# ";
+	  }
+	  opt << "option ftp_proxy " << ftpProxyLine->text() << "\n";
 	}
 	if (!loginLine->text().isEmpty()) {
 	    opt << "option proxy_username " << loginLine->text() << "\n";
@@ -480,3 +490,4 @@ void qpkg::proxy_apply()
 {
     update_iconf();
 }
+
