@@ -5,6 +5,8 @@
 #include <qtopia/qprocess.h>
 #include "qpkgbase-qtopia.h"
 #endif
+#include <vector>
+using namespace std;
 
 class qpkg: public qpkgBase
 {
@@ -32,6 +34,15 @@ public slots:
     void readFromStderr();
     void ipkgFinished();
 private:
+    class Dest {
+    public: 
+      QString name;
+      QString path;
+      Dest( const QString nname, const QString ppath ):name(nname),path(ppath){};
+      
+    };
+    vector<QString> feeds;
+    vector<Dest> dests;
     bool ipkgRunning;
     QProcess *proc;
     void updateListView(QString path);
